@@ -1,12 +1,8 @@
-/* DSTART                                                                    */
-/*                                                                           */
-/*           maildrop - mail delivery agent with filtering abilities         */
-/*                                                                           */
-/*  Copyright 1998-1999, Double Precision Inc.                               */
-/*                                                                           */
-/*  This program is distributed under the terms of the GNU General Public    */
-/*  License. See COPYING for additional information.                         */
-/* DEND                                                                      */
+/*
+** Copyright 1998 - 1999 Double Precision, Inc.
+** See COPYING for distribution information.
+*/
+
 #include	"maildircreate.h"
 #include	<sys/types.h>
 #if	HAVE_SYS_STAT_H
@@ -22,7 +18,7 @@
 #include	<stdlib.h>
 #include	"numlib/numlib.h"
 
-static const char rcsid[]="$Id: maildircreateh.c,v 1.2 1999/09/21 01:50:53 mrsam Exp $";
+static const char rcsid[]="$Id: maildircreateh.c,v 1.6 2000/10/30 03:59:56 mrsam Exp $";
 
 int maildir_try_create_hostname(const char *m,	/* Maildir */
 	const char *u,	/* Unique when creating multiple msgs by one pid */
@@ -61,9 +57,9 @@ char	pbuf[NUMBUFSIZE];
 	strcpy( (*nptr), (*tptr) );
 	memcpy( (*nptr)+l+1, "new", 3);
 
-	if (stat( (*nptr), &stat_buf) < 0 && errno == ENOENT)
+	if (stat( (*tptr), &stat_buf) < 0)
 		return (0);
 	free( *nptr );
 	free( *tptr );
-	return (-1);
+	return (1);
 }
