@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: rfc2045.c,v 1.26 2001/04/07 23:31:01 mrsam Exp $
+** $Id: rfc2045.c,v 1.28 2001/11/26 04:03:51 mrsam Exp $
 */
 #if    HAVE_CONFIG_H
 #include       "config.h"
@@ -22,6 +22,8 @@
 
 static char	*rfc2045_defcharset=0;
 
+int rfc2045_in_reformime=0;
+
 extern void rfc2045_enomem();
 
 #define	MAXLEVELS	20
@@ -152,6 +154,7 @@ struct rfc2045 *q, *r;
 	rfc2045_freeattr(p->content_type_attr);
 	rfc2045_freeattr(p->content_disposition_attr);
 
+	if (p->header)		free(p->header);
 	if (p->content_md5)	free(p->content_md5);
 	if (p->content_base)	free(p->content_base);
 	if (p->content_location)	free(p->content_location);
@@ -921,6 +924,17 @@ char	*p;
 			if (j < i && header->tokens[j].token == '=')
 			{
 				++j;
+
+				/*
+				** reformime: loose parsing due to loose
+				** parsing in MSOE, leading to viruses slipping
+				** through virus scanners if we strictly
+				** parsed the content-type header.
+				*/
+				if (rfc2045_in_reformime && j < i
+				    && header->tokens[j].token == '"')
+					i=j+1;
+
 				p=lower_paste_token(header, start);
 				if (!p)	return;
 				(*init_parameter)(r, p, header, j, i-j);
